mocks

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockDecoderInterface

type MockDecoderInterface struct {
	// contains filtered or unexported fields
}

MockDecoderInterface is a mock of decoderInterface interface.

func NewMockDecoderInterface

func NewMockDecoderInterface(ctrl *gomock.Controller) *MockDecoderInterface

NewMockDecoderInterface creates a new mock instance.

func (*MockDecoderInterface) Decode

func (m *MockDecoderInterface) Decode(arg0 []byte, arg1 map[string]any) error

Decode mocks base method.

func (*MockDecoderInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

type MockDecoderInterfaceDecodeCall

type MockDecoderInterfaceDecodeCall struct {
	*gomock.Call
}

MockDecoderInterfaceDecodeCall wrap *gomock.Call

func (*MockDecoderInterfaceDecodeCall) Do

Do rewrite *gomock.Call.Do

func (*MockDecoderInterfaceDecodeCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDecoderInterfaceDecodeCall) Return

Return rewrite *gomock.Call.Return

type MockDecoderInterfaceMockRecorder

type MockDecoderInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockDecoderInterfaceMockRecorder is the mock recorder for MockDecoderInterface.

func (*MockDecoderInterfaceMockRecorder) Decode

Decode indicates an expected call of Decode.

type MockExpanderInterface

type MockExpanderInterface struct {
	// contains filtered or unexported fields
}

MockExpanderInterface is a mock of expanderInterface interface.

func NewMockExpanderInterface

func NewMockExpanderInterface(ctrl *gomock.Controller) *MockExpanderInterface

NewMockExpanderInterface creates a new mock instance.

func (*MockExpanderInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockExpanderInterface) Expand

func (m *MockExpanderInterface) Expand(value string) (string, error)

Expand mocks base method.

type MockExpanderInterfaceExpandCall

type MockExpanderInterfaceExpandCall struct {
	*gomock.Call
}

MockExpanderInterfaceExpandCall wrap *gomock.Call

func (*MockExpanderInterfaceExpandCall) Do

Do rewrite *gomock.Call.Do

func (*MockExpanderInterfaceExpandCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockExpanderInterfaceExpandCall) Return

Return rewrite *gomock.Call.Return

type MockExpanderInterfaceMockRecorder

type MockExpanderInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockExpanderInterfaceMockRecorder is the mock recorder for MockExpanderInterface.

func (*MockExpanderInterfaceMockRecorder) Expand

Expand indicates an expected call of Expand.

type MockLookupInterface

type MockLookupInterface struct {
	// contains filtered or unexported fields
}

MockLookupInterface is a mock of lookupInterface interface.

func NewMockLookupInterface

func NewMockLookupInterface(ctrl *gomock.Controller) *MockLookupInterface

NewMockLookupInterface creates a new mock instance.

func (*MockLookupInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockLookupInterface) LookupEnv

func (m *MockLookupInterface) LookupEnv(key string) (string, bool)

LookupEnv mocks base method.

type MockLookupInterfaceLookupEnvCall

type MockLookupInterfaceLookupEnvCall struct {
	*gomock.Call
}

MockLookupInterfaceLookupEnvCall wrap *gomock.Call

func (*MockLookupInterfaceLookupEnvCall) Do

Do rewrite *gomock.Call.Do

func (*MockLookupInterfaceLookupEnvCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockLookupInterfaceLookupEnvCall) Return

Return rewrite *gomock.Call.Return

type MockLookupInterfaceMockRecorder

type MockLookupInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockLookupInterfaceMockRecorder is the mock recorder for MockLookupInterface.

func (*MockLookupInterfaceMockRecorder) LookupEnv

LookupEnv indicates an expected call of LookupEnv.

Jump to