Documentation
¶
Overview ¶
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Index ¶
- type MockDecoderInterface
- type MockDecoderInterfaceDecodeCall
- func (c *MockDecoderInterfaceDecodeCall) Do(f func([]byte, map[string]any) error) *MockDecoderInterfaceDecodeCall
- func (c *MockDecoderInterfaceDecodeCall) DoAndReturn(f func([]byte, map[string]any) error) *MockDecoderInterfaceDecodeCall
- func (c *MockDecoderInterfaceDecodeCall) Return(arg0 error) *MockDecoderInterfaceDecodeCall
- type MockDecoderInterfaceMockRecorder
- type MockExpanderInterface
- type MockExpanderInterfaceExpandCall
- func (c *MockExpanderInterfaceExpandCall) Do(f func(string) (string, error)) *MockExpanderInterfaceExpandCall
- func (c *MockExpanderInterfaceExpandCall) DoAndReturn(f func(string) (string, error)) *MockExpanderInterfaceExpandCall
- func (c *MockExpanderInterfaceExpandCall) Return(arg0 string, arg1 error) *MockExpanderInterfaceExpandCall
- type MockExpanderInterfaceMockRecorder
- type MockLookupInterface
- type MockLookupInterfaceLookupEnvCall
- func (c *MockLookupInterfaceLookupEnvCall) Do(f func(string) (string, bool)) *MockLookupInterfaceLookupEnvCall
- func (c *MockLookupInterfaceLookupEnvCall) DoAndReturn(f func(string) (string, bool)) *MockLookupInterfaceLookupEnvCall
- func (c *MockLookupInterfaceLookupEnvCall) Return(arg0 string, arg1 bool) *MockLookupInterfaceLookupEnvCall
- type MockLookupInterfaceMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockDecoderInterface ¶
type MockDecoderInterface struct {
// contains filtered or unexported fields
}
MockDecoderInterface is a mock of decoderInterface interface.
func NewMockDecoderInterface ¶
func NewMockDecoderInterface(ctrl *gomock.Controller) *MockDecoderInterface
NewMockDecoderInterface creates a new mock instance.
func (*MockDecoderInterface) Decode ¶
func (m *MockDecoderInterface) Decode(arg0 []byte, arg1 map[string]any) error
Decode mocks base method.
func (*MockDecoderInterface) EXPECT ¶
func (m *MockDecoderInterface) EXPECT() *MockDecoderInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockDecoderInterfaceDecodeCall ¶
MockDecoderInterfaceDecodeCall wrap *gomock.Call
func (*MockDecoderInterfaceDecodeCall) Do ¶
func (c *MockDecoderInterfaceDecodeCall) Do(f func([]byte, map[string]any) error) *MockDecoderInterfaceDecodeCall
Do rewrite *gomock.Call.Do
func (*MockDecoderInterfaceDecodeCall) DoAndReturn ¶
func (c *MockDecoderInterfaceDecodeCall) DoAndReturn(f func([]byte, map[string]any) error) *MockDecoderInterfaceDecodeCall
DoAndReturn rewrite *gomock.Call.DoAndReturn
func (*MockDecoderInterfaceDecodeCall) Return ¶
func (c *MockDecoderInterfaceDecodeCall) Return(arg0 error) *MockDecoderInterfaceDecodeCall
Return rewrite *gomock.Call.Return
type MockDecoderInterfaceMockRecorder ¶
type MockDecoderInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockDecoderInterfaceMockRecorder is the mock recorder for MockDecoderInterface.
func (*MockDecoderInterfaceMockRecorder) Decode ¶
func (mr *MockDecoderInterfaceMockRecorder) Decode(arg0, arg1 any) *MockDecoderInterfaceDecodeCall
Decode indicates an expected call of Decode.
type MockExpanderInterface ¶
type MockExpanderInterface struct {
// contains filtered or unexported fields
}
MockExpanderInterface is a mock of expanderInterface interface.
func NewMockExpanderInterface ¶
func NewMockExpanderInterface(ctrl *gomock.Controller) *MockExpanderInterface
NewMockExpanderInterface creates a new mock instance.
func (*MockExpanderInterface) EXPECT ¶
func (m *MockExpanderInterface) EXPECT() *MockExpanderInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockExpanderInterfaceExpandCall ¶
MockExpanderInterfaceExpandCall wrap *gomock.Call
func (*MockExpanderInterfaceExpandCall) Do ¶
func (c *MockExpanderInterfaceExpandCall) Do(f func(string) (string, error)) *MockExpanderInterfaceExpandCall
Do rewrite *gomock.Call.Do
func (*MockExpanderInterfaceExpandCall) DoAndReturn ¶
func (c *MockExpanderInterfaceExpandCall) DoAndReturn(f func(string) (string, error)) *MockExpanderInterfaceExpandCall
DoAndReturn rewrite *gomock.Call.DoAndReturn
func (*MockExpanderInterfaceExpandCall) Return ¶
func (c *MockExpanderInterfaceExpandCall) Return(arg0 string, arg1 error) *MockExpanderInterfaceExpandCall
Return rewrite *gomock.Call.Return
type MockExpanderInterfaceMockRecorder ¶
type MockExpanderInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockExpanderInterfaceMockRecorder is the mock recorder for MockExpanderInterface.
func (*MockExpanderInterfaceMockRecorder) Expand ¶
func (mr *MockExpanderInterfaceMockRecorder) Expand(value any) *MockExpanderInterfaceExpandCall
Expand indicates an expected call of Expand.
type MockLookupInterface ¶
type MockLookupInterface struct {
// contains filtered or unexported fields
}
MockLookupInterface is a mock of lookupInterface interface.
func NewMockLookupInterface ¶
func NewMockLookupInterface(ctrl *gomock.Controller) *MockLookupInterface
NewMockLookupInterface creates a new mock instance.
func (*MockLookupInterface) EXPECT ¶
func (m *MockLookupInterface) EXPECT() *MockLookupInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockLookupInterfaceLookupEnvCall ¶
MockLookupInterfaceLookupEnvCall wrap *gomock.Call
func (*MockLookupInterfaceLookupEnvCall) Do ¶
func (c *MockLookupInterfaceLookupEnvCall) Do(f func(string) (string, bool)) *MockLookupInterfaceLookupEnvCall
Do rewrite *gomock.Call.Do
func (*MockLookupInterfaceLookupEnvCall) DoAndReturn ¶
func (c *MockLookupInterfaceLookupEnvCall) DoAndReturn(f func(string) (string, bool)) *MockLookupInterfaceLookupEnvCall
DoAndReturn rewrite *gomock.Call.DoAndReturn
func (*MockLookupInterfaceLookupEnvCall) Return ¶
func (c *MockLookupInterfaceLookupEnvCall) Return(arg0 string, arg1 bool) *MockLookupInterfaceLookupEnvCall
Return rewrite *gomock.Call.Return
type MockLookupInterfaceMockRecorder ¶
type MockLookupInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockLookupInterfaceMockRecorder is the mock recorder for MockLookupInterface.
func (*MockLookupInterfaceMockRecorder) LookupEnv ¶
func (mr *MockLookupInterfaceMockRecorder) LookupEnv(key any) *MockLookupInterfaceLookupEnvCall
LookupEnv indicates an expected call of LookupEnv.